==> filanco-domain-api-1.2.1.zip: examples/init.php <==
<?php

use Filanco\Domain\RegistrarApiLogInterface;
use Filanco\Domain\RegistrarInterface;

require_once __DIR__ . '/../vendor/autoload.php';

class Registrar implements RegistrarInterface
{
    public function getId()
    {
    }

    public function getSystemName()
    {
        return 'domenus';
    }

    public function getName()
    {
    }

    public function getRegistrantName()
    {
    }

    public function getLogin()
    {
        return 'CL01-ORG-DMS';
    }

    public function getPassword()
    {
        return 'o6R8jeFo3Iw2dQkzWOEG';
    }

    public function getPort()
    {
        return 443;
    }

    public function getUri()
    {
        return 'api.domenus.ru';
    }

    public function getContentType()
    {
        return 'xml';
    }
}

class Logger implements RegistrarApiLogInterface
{

    /**
     * @param string $registrar_name Название регистратора
     */
    public function setWho($registrar_name)
    {
        // TODO: Implement setWho() method.
    }

    /**
     * @param string $request Запрос
     */
    public function setRequest($request)
    {
        // TODO: Implement setRequest() method.
    }

    /**
     * @param string $response Ответ
     */
    public function setResponse($response)
    {
        // TODO: Implement setResponse() method.
    }

    /**
     * @param string $stamp Время когда выполнялся запрос
     */
    public function setStamp($stamp)
    {
        // TODO: Implement setStamp() method.
    }

    public function save()
    {
        // TODO: Implement save() method.
    }
}

==> filanco-domain-api-3.0.1.zip: examples/init.php <==
<?php

use Filanco\Domain\RegistrarApiLogInterface;
use Filanco\Domain\RegistrarInterface;

require_once __DIR__ . '/../vendor/autoload.php';

class Registrar implements RegistrarInterface
{
    public $name;
    public $port;
    public $login;
    public $password;
    public $uri;
    public $type;

    public function __construct($mas)
    {
        $this->name = $mas['name'];
        $this->port = $mas['port'];
        $this->type = $mas['type'];
        $this->uri = $mas['uri'];
        $this->login = $mas['login'];
        $this->password = $mas['password'];
    }
    public function getId()
    {
    }

    public function getSystemName()
    {
        return $this->name;
    }

    public function getName()
    {
    }

    public function getRegistrantName()
    {
    }

    public function getLogin()
    {
        return $this->login;
    }

    public function getPassword()
    {
        return $this->password;
    }

    public function getPort()
    {
        return $this->port;
    }

    public function getUri()
    {
        return $this->uri;
    }

    public function getContentType()
    {
        return $this->type;
    }
}

class Logger implements RegistrarApiLogInterface
{

    /**
     * @param string $registrar_name Название регистратора
     */
    public function setWho($registrar_name)
    {
        // TODO: Implement setWho() method.
    }

    /**
     * @param string $request Запрос
     */
    public function setRequest($request)
    {
        // TODO: Implement setRequest() method.
    }

    /**
     * @param string $response Ответ
     */
    public function setResponse($response)
    {
        // TODO: Implement setResponse() method.
    }

    /**
     * @param string $stamp Время когда выполнялся запрос
     */
    public function setStamp($stamp)
    {
        // TODO: Implement setStamp() method.
    }

    public function save()
    {
        // TODO: Implement save() method.
    }
}
